# Preprocessing

*TODO, this page just contains some notes for now.*

## Windows
%SystemDrive% - According to [MSDN](https://msdn.microsoft.com/en-us/library/cc231436.aspx) %SystemDrive% is derived from the first 2 letters of %SystemRoot%